pub struct AuthPlaintext { /* private fields */ }Expand description
Represents plaintext with an associated MAC.
Implementations
Sourceimpl AuthPlaintext
impl AuthPlaintext
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Dumps the bytes.
NOTE: The MAC length is fixed in this implementation, so there is no immediate need to delimit the plaintext from the tag.
Sourcepub fn from_bytes(bytes: Vec<u8>) -> Option<AuthPlaintext>
pub fn from_bytes(bytes: Vec<u8>) -> Option<AuthPlaintext>
Builds an AuthPlaintext struct from raw bytes. Returns None when the input is
too short.